@@ -6,7 +6,7 @@ from subprocess import Popen, PIPE
 from sys import platform, exit
 
 
-__version__ = "0.1.12"
+__version__ = "0.1.13"
 
 gunicorns = {} # gunicorn master process names/pids.
 selected_pid = None # Process ID of currently selected gunicorn master process.
@@ -21,7 +21,7 @@ up/down changes selection
 no_gunicorns = "Aww, no gunicorns are running!!"
 screen_width = None
 foreground_colour = curses.COLOR_BLACK
-background_colour = curses.COLOR_BLUE
+background_colour = curses.COLOR_GREEN
 
 
 if platform == "darwin":
